@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of the python-chess library.
-# Copyright (C) 2016-2017 Niklas Fiekas <niklas.fiekas@backscattering.de>
+# Copyright (C) 2016-2018 Niklas Fiekas <niklas.fiekas@backscattering.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -152,6 +152,13 @@ class SuicideBoard(chess.Board):
         else:
             return not any(self.generate_pseudo_legal_captures())
 
+    def _transposition_key(self):
+        if self.has_chess960_castling_rights():
+            return (super(SuicideBoard, self)._transposition_key(),
+                    self.kings & self.promoted)
+        else:
+            return super(SuicideBoard, self)._transposition_key()
+
     def board_fen(self, promoted=None):
         if promoted is None:
             promoted = self.has_chess960_castling_rights()
@@ -684,6 +691,7 @@ class CrazyhouseBoard(chess.Board):
 
     def _transposition_key(self):
         return (super(CrazyhouseBoard, self)._transposition_key(),
+                self.promoted,
                 str(self.pockets[chess.WHITE]), str(self.pockets[chess.BLACK]))
 
     def legal_drop_squares_mask(self):
